==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CrosshairLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var CrosshairLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CrosshairLayerDescription, _super);
    function CrosshairLayerDescription() {
        var _this = _super.call(this) || this;
        _this.ed = null;
        _this.eh = null;
        _this.ef = null;
        _this.eg = null;
        _this.dg = false;
        _this.de = false;
        _this.el = null;
        _this.ej = null;
        _this.dk = 0;
        _this.d9 = 0;
        _this.ek = null;
        _this.dm = 0;
        _this.dp = 0;
        _this.dn = 0;
        _this.dl = 0;
        _this.dt = 0;
        _this.dv = 0;
        _this.du = 0;
        _this.ds = 0;
        _this.dq = 0;
        _this.eo = null;
        _this.em = null;
        _this.dr = 0;
        _this.ea = 0;
        _this.en = null;
        _this.dw = 0;
        _this.ei = null;
        _this.ee = null;
        _this.df = false;
        return _this;
    }
    CrosshairLayerDescription.prototype.get_type = function () {
        return "CrosshairLayer";
    };
    Object.defineProperty(CrosshairLayerDescription.prototype, "horizontalLineStroke", {
        get: function () {
            return this.ed;
        },
        set: function (a) {
            this.ed = a;
            this.e("HorizontalLineStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "verticalLineStroke", {
        get: function () {
            return this.eh;
        },
        set: function (a) {
            this.eh = a;
            this.e("VerticalLineStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.ef;
        },
        set: function (a) {
            this.ef = a;
            this.e("TargetSeriesName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.eg;
        },
        set: function (a) {
            this.eg = a;
            this.e("TargetSeriesRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.dg;
        },
        set: function (a) {
            this.dg = a;
            this.e("UseInterpolation");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "isAxisAnnotationEnabled", {
        get: function () {
            return this.de;
        },
        set: function (a) {
            this.de = a;
            this.e("IsAxisAnnotationEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationTextColor", {
        get: function () {
            return this.el;
        },
        set: function (a) {
            this.el = a;
            this.e("XAxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationBackground", {
        get: function () {
            return this.ej;
        },
        set: function (a) {
            this.ej = a;
            this.e("XAxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.dk;
        },
        set: function (a) {
            this.dk = a;
            this.e("XAxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.d9;
        },
        set: function (a) {
            this.d9 = a;
            this.e("XAxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationOutline", {
        get: function () {
            return this.ek;
        },
        set: function (a) {
            this.ek = a;
            this.e("XAxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingLeft", {
        get: function () {
            return this.dm;
        },
        set: function (a) {
            this.dm = a;
            this.e("XAxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingTop", {
        get: function () {
            return this.dp;
        },
        set: function (a) {
            this.dp = a;
            this.e("XAxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingRight", {
        get: function () {
            return this.dn;
        },
        set: function (a) {
            this.dn = a;
            this.e("XAxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingBottom", {
        get: function () {
            return this.dl;
        },
        set: function (a) {
            this.dl = a;
            this.e("XAxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingLeft", {
        get: function () {
            return this.dt;
        },
        set: function (a) {
            this.dt = a;
            this.e("YAxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingTop", {
        get: function () {
            return this.dv;
        },
        set: function (a) {
            this.dv = a;
            this.e("YAxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingRight", {
        get: function () {
            return this.du;
        },
        set: function (a) {
            this.du = a;
            this.e("YAxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingBottom", {
        get: function () {
            return this.ds;
        },
        set: function (a) {
            this.ds = a;
            this.e("YAxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationStrokeThickness", {
        get: function () {
            return this.dq;
        },
        set: function (a) {
            this.dq = a;
            this.e("XAxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationTextColor", {
        get: function () {
            return this.eo;
        },
        set: function (a) {
            this.eo = a;
            this.e("YAxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationBackground", {
        get: function () {
            return this.em;
        },
        set: function (a) {
            this.em = a;
            this.e("YAxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.dr;
        },
        set: function (a) {
            this.dr = a;
            this.e("YAxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.ea;
        },
        set: function (a) {
            this.ea = a;
            this.e("YAxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationOutline", {
        get: function () {
            return this.en;
        },
        set: function (a) {
            this.en = a;
            this.e("YAxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationStrokeThickness", {
        get: function () {
            return this.dw;
        },
        set: function (a) {
            this.dw = a;
            this.e("YAxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "verticalLineVisibility", {
        get: function () {
            return this.ei;
        },
        set: function (a) {
            this.ei = a;
            this.e("VerticalLineVisibility");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "horizontalLineVisibility", {
        get: function () {
            return this.ee;
        },
        set: function (a) {
            this.ee = a;
            this.e("HorizontalLineVisibility");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "skipUnknownValues", {
        get: function () {
            return this.df;
        },
        set: function (a) {
            this.df = a;
            this.e("SkipUnknownValues");
        },
        enumerable: false,
        configurable: true
    });
    CrosshairLayerDescription.$t = markType(CrosshairLayerDescription, 'CrosshairLayerDescription', AnnotationLayerDescription.$);
    return CrosshairLayerDescription;
}(AnnotationLayerDescription));
export { CrosshairLayerDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/CrosshairLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var CrosshairLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CrosshairLayerDescription, _super);
    function CrosshairLayerDescription() {
        var _this = _super.call(this) || this;
        _this.hd = null;
        _this.hh = null;
        _this.hf = null;
        _this.hg = null;
        _this.gh = false;
        _this.gf = false;
        _this.hm = null;
        _this.hj = null;
        _this.gl = 0;
        _this.g9 = 0;
        _this.hl = null;
        _this.gn = 0;
        _this.gp = 0;
        _this.go = 0;
        _this.gm = 0;
        _this.gt = 0;
        _this.gv = 0;
        _this.gu = 0;
        _this.gs = 0;
        _this.gq = 0;
        _this.hq = null;
        _this.hn = null;
        _this.gr = 0;
        _this.ha = 0;
        _this.hp = null;
        _this.gw = 0;
        _this.hi = null;
        _this.he = null;
        _this.gg = false;
        _this.hk = null;
        _this.ho = null;
        return _this;
    }
    CrosshairLayerDescription.prototype.get_type = function () {
        return "CrosshairLayer";
    };
    Object.defineProperty(CrosshairLayerDescription.prototype, "horizontalLineStroke", {
        get: function () {
            return this.hd;
        },
        set: function (a) {
            this.hd = a;
            this.g("HorizontalLineStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "verticalLineStroke", {
        get: function () {
            return this.hh;
        },
        set: function (a) {
            this.hh = a;
            this.g("VerticalLineStroke");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.hf;
        },
        set: function (a) {
            this.hf = a;
            this.g("TargetSeriesName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.hg;
        },
        set: function (a) {
            this.hg = a;
            this.g("TargetSeriesRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.gh;
        },
        set: function (a) {
            this.gh = a;
            this.g("UseInterpolation");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "isAxisAnnotationEnabled", {
        get: function () {
            return this.gf;
        },
        set: function (a) {
            this.gf = a;
            this.g("IsAxisAnnotationEnabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationTextColor", {
        get: function () {
            return this.hm;
        },
        set: function (a) {
            this.hm = a;
            this.g("XAxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationBackground", {
        get: function () {
            return this.hj;
        },
        set: function (a) {
            this.hj = a;
            this.g("XAxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.gl;
        },
        set: function (a) {
            this.gl = a;
            this.g("XAxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.g("XAxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationOutline", {
        get: function () {
            return this.hl;
        },
        set: function (a) {
            this.hl = a;
            this.g("XAxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingLeft", {
        get: function () {
            return this.gn;
        },
        set: function (a) {
            this.gn = a;
            this.g("XAxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingTop", {
        get: function () {
            return this.gp;
        },
        set: function (a) {
            this.gp = a;
            this.g("XAxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingRight", {
        get: function () {
            return this.go;
        },
        set: function (a) {
            this.go = a;
            this.g("XAxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationPaddingBottom", {
        get: function () {
            return this.gm;
        },
        set: function (a) {
            this.gm = a;
            this.g("XAxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingLeft", {
        get: function () {
            return this.gt;
        },
        set: function (a) {
            this.gt = a;
            this.g("YAxisAnnotationPaddingLeft");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingTop", {
        get: function () {
            return this.gv;
        },
        set: function (a) {
            this.gv = a;
            this.g("YAxisAnnotationPaddingTop");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingRight", {
        get: function () {
            return this.gu;
        },
        set: function (a) {
            this.gu = a;
            this.g("YAxisAnnotationPaddingRight");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationPaddingBottom", {
        get: function () {
            return this.gs;
        },
        set: function (a) {
            this.gs = a;
            this.g("YAxisAnnotationPaddingBottom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationStrokeThickness", {
        get: function () {
            return this.gq;
        },
        set: function (a) {
            this.gq = a;
            this.g("XAxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationTextColor", {
        get: function () {
            return this.hq;
        },
        set: function (a) {
            this.hq = a;
            this.g("YAxisAnnotationTextColor");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationBackground", {
        get: function () {
            return this.hn;
        },
        set: function (a) {
            this.hn = a;
            this.g("YAxisAnnotationBackground");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationBackgroundCornerRadius", {
        get: function () {
            return this.gr;
        },
        set: function (a) {
            this.gr = a;
            this.g("YAxisAnnotationBackgroundCornerRadius");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationInterpolatedValuePrecision", {
        get: function () {
            return this.ha;
        },
        set: function (a) {
            this.ha = a;
            this.g("YAxisAnnotationInterpolatedValuePrecision");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationOutline", {
        get: function () {
            return this.hp;
        },
        set: function (a) {
            this.hp = a;
            this.g("YAxisAnnotationOutline");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationStrokeThickness", {
        get: function () {
            return this.gw;
        },
        set: function (a) {
            this.gw = a;
            this.g("YAxisAnnotationStrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "verticalLineVisibility", {
        get: function () {
            return this.hi;
        },
        set: function (a) {
            this.hi = a;
            this.g("VerticalLineVisibility");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "horizontalLineVisibility", {
        get: function () {
            return this.he;
        },
        set: function (a) {
            this.he = a;
            this.g("HorizontalLineVisibility");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "skipUnknownValues", {
        get: function () {
            return this.gg;
        },
        set: function (a) {
            this.gg = a;
            this.g("SkipUnknownValues");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "xAxisAnnotationFormatLabelRef", {
        get: function () {
            return this.hk;
        },
        set: function (a) {
            this.hk = a;
            this.g("XAxisAnnotationFormatLabelRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CrosshairLayerDescription.prototype, "yAxisAnnotationFormatLabelRef", {
        get: function () {
            return this.ho;
        },
        set: function (a) {
            this.ho = a;
            this.g("YAxisAnnotationFormatLabelRef");
        },
        enumerable: false,
        configurable: true
    });
    CrosshairLayerDescription.$t = markType(CrosshairLayerDescription, 'CrosshairLayerDescription', AnnotationLayerDescription.$);
    return CrosshairLayerDescription;
}(AnnotationLayerDescription));
export { CrosshairLayerDescription };
